@@ -10,7 +10,7 @@ import urllib3
 from mdast_cli.distribution_systems.app_center import AppCenter
 from mdast_cli.distribution_systems.appgallery import appgallery_download_app
 from mdast_cli.distribution_systems.appstore import AppStore
-from mdast_cli.distribution_systems.firebase import Firebase
+from mdast_cli.distribution_systems.firebase import firebase_download_app
 from mdast_cli.distribution_systems.google_play import GooglePlay
 from mdast_cli.distribution_systems.nexus import NexusRepository
 from mdast_cli.distribution_systems.nexus2 import Nexus2Repository
@@ -82,33 +82,15 @@ def parse_args():
                              'This argument is required if distribution system set to "appcenter"')
 
     # Arguments for Firebase
-    parser.add_argument('--firebase_project_id', type=str,
-                        help='Project id for firebase where mobile application is located.'
+    parser.add_argument('--firebase_project_number', type=int,
+                        help='Project number for firebase where mobile application is located.'
                              ' This argument is required if distribution system set to "firebase"')
     parser.add_argument('--firebase_app_id', type=str,
                         help='Application id for firebase where mobile application is located.'
                              ' This argument is required if distribution system set to "firebase"')
-    parser.add_argument('--firebase_app_code', type=str,
-                        help='Application code for firebase where mobile application is located.'
+    parser.add_argument('--firebase_account_json_path', type=str,
+                        help='json.'
                              ' This argument is required if distribution system set to "firebase"')
-    parser.add_argument('--firebase_api_key', type=str,
-                        help='Api code for firebase where mobile application is located.'
-                             ' This argument is required if distribution system set to "firebase"')
-    parser.add_argument('--firebase_SID_cookie', type=str,
-                        help='SID cookie for firebase authentication  via google sso.'
-                             ' This argument is required if distribution system set to "firebase"')
-    parser.add_argument('--firebase_HSID_cookie', type=str,
-                        help='HSID cookie for firebase authentication  via google sso.'
-                             ' This argument is required if distribution system set to "firebase"')
-    parser.add_argument('--firebase_SSID_cookie', type=str,
-                        help='SSID cookie for firebase authentication  via google sso.'
-                             ' This argument is required if distribution system set to "firebase"')
-    parser.add_argument('--firebase_APISID_cookie', type=str,
-                        help='APISID cookie for firebase authentication  via google sso.'
-                             ' This argument is required if distribution system set to "firebase"')
-    parser.add_argument('--firebase_SAPISID_cookie', type=str,
-                        help='SAPISID cookie for firebase authentication  via google sso.'
-                             ' This argument required if distribution system set to "firebase"')
     parser.add_argument('--firebase_file_extension', type=str,
                         help='File extension(apk or ipa) for downloaded application.'
                              ' This argument is required if distribution system set to "firebase"',
@@ -214,9 +196,12 @@ def parse_args():
     parser.add_argument('--company_id', type=int, help='Company id for starting scan', required=(not '-d'))
     parser.add_argument('--token', type=str, help='CI/CD Token for start scan and get results', required=(not '-d'))
     parser.add_argument('--architecture_id', type=int, help='Architecture id to perform scan')
-    parser.add_argument('--profile_id', type=int,
-                        help='Profile id for scan. If not set - autocreate project and profile')
+    parser.add_argument('--profile_id', type=int, default=None,
+                        help='Profile id for scan. If not set - autocreate profile')
+    parser.add_argument('--project_id', type=int, default=None,
+                        help='Project id for scan. Only if you want to autocreate profile in existing project')
     parser.add_argument('--testcase_id', type=int, help='Testcase id. If not set - manual scan')
+    parser.add_argument('--appium_script_path', type=str, help='Appium script path for autoscan with Stingray appium')
     parser.add_argument('--summary_report_json_file_name', type=str,
                         help='Name for the json file with summary results in structured format')
     parser.add_argument('--pdf_report_file_name', type=str, help='Name for the pdf report file.')
@@ -266,20 +251,12 @@ def parse_args():
                      'arguments to be set')
 
     elif args.distribution_system == 'firebase' and (
-            args.firebase_project_id is None or
+            args.firebase_project_number is None or
             args.firebase_app_id is None or
-            args.firebase_app_code is None or
-            args.firebase_api_key is None or
-            args.firebase_SID_cookie is None or
-            args.firebase_HSID_cookie is None or
-            args.firebase_SSID_cookie is None or
-            args.firebase_APISID_cookie is None or
-            args.firebase_SAPISID_cookie is None or
+            args.firebase_account_json_path is None or
             args.firebase_file_extension is None):
-        parser.error('"--distribution_system nexus" requires "--firebase_project_id", "--firebase_app_id", '
-                     '"--firebase_app_code", "--firebase_api_key", "--firebase_api_key", "--firebase_SID_cookie", '
-                     '"--firebase_HSID_cookie", "--firebase_SSID_cookie", "--firebase_APISID_cookie", '
-                     '"--firebase_SAPISID_cookie", "--firebase_file_extension" arguments to be set')
+        parser.error('"--distribution_system firebase" requires "--firebase_project_number", "--firebase_app_id", '
+                     '"--firebase_account_json_path", "--firebase_file_extension" arguments to be set')
 
     elif args.distribution_system == 'appstore' and (
             (args.appstore_app_id is None and args.appstore_bundle_id is None) or
@@ -320,7 +297,9 @@ def main():
         architecture = arguments.architecture_id
         token = arguments.token
         profile_id = arguments.profile_id
+        project_id = arguments.project_id
         testcase_id = arguments.testcase_id
+        appium_script_path = arguments.appium_script_path
         json_summary_file_name = arguments.summary_report_json_file_name
         pdf_report_file_name = arguments.pdf_report_file_name
         not_wait_scan_end = arguments.nowait
@@ -337,9 +316,9 @@ def main():
             app_file = arguments.file_path
 
         elif distribution_system == 'appcenter':
-            appcenter = AppCenter(arguments.appcenter_token,
-                                  arguments.appcenter_owner_name)
+            appcenter = AppCenter(arguments.appcenter_token)
             app_file = appcenter.download_app(download_path,
+                                              arguments.appcenter_owner_name,
                                               arguments.appcenter_app_name,
                                               arguments.appcenter_app_version,
                                               arguments.appcenter_release_id)
@@ -366,18 +345,12 @@ def main():
                                                       arguments.nexus2_file_name)
 
         elif distribution_system == 'firebase':
-            firebase = Firebase(arguments.firebase_api_key,
-                                arguments.firebase_SID_cookie,
-                                arguments.firebase_HSID_cookie,
-                                arguments.firebase_SSID_cookie,
-                                arguments.firebase_APISID_cookie,
-                                arguments.firebase_SAPISID_cookie)
-            app_file = firebase.download_app(download_path,
-                                             arguments.firebase_project_id,
+            app_file = firebase_download_app(download_path,
+                                             arguments.firebase_project_number,
                                              arguments.firebase_app_id,
-                                             arguments.firebase_app_code,
-                                             arguments.firebase_file_extension,
-                                             arguments.firebase_file_name)
+                                             arguments.firebase_account_json_path,
+                                             arguments.firebase_file_name,
+                                             arguments.firebase_file_extension)
 
         elif distribution_system == 'appstore':
             if arguments.appstore_password and arguments.appstore_2FA:
@@ -452,12 +425,15 @@ def main():
             logger.warning("Testcase with this id does not exist or you use old version of system. Trying to use "
                            "architecture from command line params.")
 
-    if testcase_id is None:
-        logger.info(f'Manual scan with profile id: {profile_id} and file located in {app_file},'
+    if testcase_id:
+        logger.info(f'Autoscan(Stingray) with test case id: '
+                    f'{testcase_id}, profile id: {profile_id} and file: {app_file}, architecture id is {architecture}')
+    elif appium_script_path:
+        logger.info(f'Autoscan(Appium) with  profile id: {profile_id} and file: {app_file},'
                     f' architecture id is {architecture}')
     else:
-        logger.info(f'Auto scan with test case id: '
-                    f'{testcase_id}, profile id: {profile_id} and file: {app_file}, architecture id is {architecture}')
+        logger.info(f'Manual scan with profile id: {profile_id} and file located in {app_file},'
+                    f' architecture id is {architecture}')
 
     logger.info('Check if this version of application was already uploaded..')
     if appstore_app_md5:
@@ -480,53 +456,33 @@ def main():
         logger.info(f"Application uploaded successfully. Application id: {application['id']}")
 
     logger.info(f"Creating scan for application {application['id']}")
-
-    if 'Android' in architecture_type.get('name', ''):
-        if not testcase_id:
-            if profile_id:
-                create_dast_resp = mdast.create_manual_scan(profile_id=profile_id,
-                                                            app_id=application['id'],
-                                                            arch_id=architecture)
-            else:
-                create_dast_resp = mdast.create_manual_scan_autocreate_profile(app_id=application['id'],
-                                                                               arch_id=architecture)
-                dast_info = create_dast_resp.json()
-                logger.info(f"Project and profile was created/found successfully."
-                            f" Project id: {dast_info['project']['id']}, profile id: {dast_info['profile']['id']}")
-            scan_type = 'manual'
-        else:
-            create_dast_resp = mdast.create_auto_scan(profile_id=profile_id,
-                                                      app_id=application['id'],
-                                                      arch_id=architecture,
-                                                      test_case_id=testcase_id)
-            scan_type = 'auto'
-    elif 'iOS' in architecture_type.get('name', ''):
-        if profile_id:
-            create_dast_resp = mdast.create_manual_scan(profile_id=profile_id,
-                                                        app_id=application['id'],
-                                                        arch_id=architecture)
-        else:
-            create_dast_resp = mdast.create_manual_scan_autocreate_profile(app_id=application['id'],
-                                                                           arch_id=architecture)
-            dast_info = create_dast_resp.json()
-            logger.info(f"Project and profile was created/found successfully."
-                        f" Project id: {dast_info['project']['id']}, profile id: {dast_info['profile']['id']}")
-        scan_type = 'manual'
+    if testcase_id:
+        create_dast_resp = mdast.create_auto_scan(project_id, profile_id, application['id'], architecture, testcase_id)
+        scan_type = 'auto_stingray'
+    elif appium_script_path:
+        create_dast_resp = mdast.create_appium_scan(project_id, profile_id, application['id'], architecture,
+                                                    appium_script_path)
+        scan_type = 'auto_appium'
     else:
-        logger.error("Cannot create scan - unknown architecture")
-        sys.exit(1)
-
+        create_dast_resp = mdast.create_manual_scan(project_id, profile_id, application['id'], architecture)
+        scan_type = 'manual'
     if create_dast_resp.status_code != 201:
         logger.error(f'Error while creating scan: {create_dast_resp.text}')
         sys.exit(1)
 
+    dast_info = create_dast_resp.json()
+    logger.info(f"Project and profile was created/found successfully."
+                f" Project id: {dast_info['project']['id']}, profile id: {dast_info['profile']['id']}")
+
     dast = create_dast_resp.json()
     if 'id' not in dast and dast.get('id', '') != '':
         logger.error(f'Something went wrong while creating scan: {dast}')
         sys.exit(1)
 
-    if scan_type == 'auto':
-        logger.info(f"Autoscan was created successfully. Scan id: {dast['id']}")
+    if scan_type == 'auto_stingray':
+        logger.info(f"Autoscan(Stingray) was created successfully. Scan id: {dast['id']}")
+    elif scan_type == 'auto_appium':
+        logger.info(f"Autoscan(Appium) was created successfully. Scan id: {dast['id']}")
     else:
         logger.info(f"Manual scan was created successfully. Scan id: {dast['id']}")
 
